@@ -19,16 +19,26 @@ import sys
 import os 
 # Reader imports
 import example_pkg
-from example_pkg import mod1
-from example_pkg import mod2
+from example_pkg.mod1 import *
+from example_pkg.mod2 import *
 
 def main():  # type: () -> None
     """Calculate data a+b"""
-    def calc_data(a,b):
-        return a+b
-    mod1.load_data()
-    x= mod1.Products()
-    print(x)
+    y= Furniture()
+    dict1 = y.parsing()
+    print(dict1)
+    # list2 = []
+    # for k,v in dict1.items():
+    #     list2.append(y.parsing2(v).copy())
+
+    # list2 = list(filter(None, list2)) 
+    # print(list2)
+    # list3 = []   
+    # for l in list2:
+    #     for k,v in l.items():
+    #         list3.append(y.parsing3(v).copy())
+    return dict1
+
 
 
 if __name__ == "__main__":
